//
//  YHBasePlayerViewController.swift
//  galaxy
//
//  Created by alexzzw on 2024/11/25.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import AgoraRtcKit
import UIKit

class YHBasePlayerViewController: YHBaseViewController {
    // MARK: - Properties

    var playerKit: AgoraRtcMediaPlayerProtocol!
    var agoraKit: AgoraRtcEngineKit!

    // MARK: - UI Components

    lazy var containerView: UIView = {
        let view = UIView()
        view.backgroundColor = .black
        return view
    }()
    
    lazy var bgIcon: UIImageView = {
        let imageView = UIImageView()
        if let path = Bundle.main.path(forResource: "live_room_test_bg", ofType: "png") {
            imageView.image = UIImage(contentsOfFile: path)
        }
        return imageView
    }()

    lazy var playerView: UIView = {
        let view = UIView()
        view.backgroundColor = .clear
        return view
    }()

    private lazy var controlView: YHPlayerControlView = {
        let view = YHPlayerControlView()
        view.delegate = self
        return view
    }()
    
    lazy var topBarView: YHPlayerTopBarView = {
        let view = YHPlayerTopBarView(frame: CGRect.init(x: 0, y: 0, width: KScreenWidth, height: k_Height_NavigationtBarAndStatuBar))
        return view
    }()

    // MARK: - Lifecycle

    override func viewDidLoad() {
        super.viewDidLoad()
        setupUI()
        setupAgoraKit()
    }

    // MARK: - Setup

    private func setupUI() {
        gk_navBarAlpha = 0
        gk_navigationBar.isHidden = true
        view.backgroundColor = .black

        view.addSubview(containerView)
        //containerView.addSubview(bgIcon)
        containerView.addSubview(playerView)
        containerView.addSubview(topBarView)

        setupConstraints()
    }

    private func setupConstraints() {
        containerView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
        
//        bgIcon.snp.makeConstraints { make in
//            make.edges.equalToSuperview()
//        }

        playerView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
        
        topBarView.snp.makeConstraints { make in
            make.top.left.right.equalToSuperview()
            make.height.equalTo(k_Height_NavigationtBarAndStatuBar)
        }

//        controlView.snp.makeConstraints { make in
//            make.edges.equalToSuperview()
//        }
    }

    private func setupAgoraKit() {
        let config = AgoraRtcEngineConfig()
        config.appId = YhConstant.AgoraRtcKit.appId
        config.areaCode = .global
        config.channelProfile = .liveBroadcasting
        agoraKit = AgoraRtcEngineKit.sharedEngine(with: config, delegate: self)

        playerKit = agoraKit.createMediaPlayer(with: self)
        playerKit.setView(playerView)
        playerKit.setRenderMode(.fit)
    }
}

extension YHBasePlayerViewController: YHMediaPlayerViewDelegate {
    // MARK: - MediaPlayerViewDelegate

    func didTapPlayButton() {
        if playerKit.getPlayerState() == .playing {
            playerKit.pause()
        } else {
            playerKit.play()
        }
    }

    func didTapStopButton() {
        playerKit.stop()
    }

    func didSeekToPosition(_ position: Float) {
        let duration = playerKit.getDuration()
        let seekPosition = Int64(Float(duration) * position)
        playerKit.seek(toPosition: Int(seekPosition))
    }

    func didChangeQuality(_ quality: YHVideoQuality) {
        // 根据不同清晰度切换播放源
        switch quality {
        case .auto:
            // 自动码率逻辑
            break
        case .sd:
            // 切换到标清源
            break
        case .hd:
            // 切换到高清源
            break
        case .fhd:
            // 切换到超清源
            break
        }
    }

    func didToggleFullscreen() {
        // 切换全屏
        if UIDevice.current.orientation.isPortrait {
            let value = UIInterfaceOrientation.landscapeRight.rawValue
            UIDevice.current.setValue(value, forKey: "orientation")
        } else {
            let value = UIInterfaceOrientation.portrait.rawValue
            UIDevice.current.setValue(value, forKey: "orientation")
        }
    }
}

extension YHBasePlayerViewController: AgoraRtcMediaPlayerDelegate {
    // MARK: - AgoraRtcMediaPlayerDelegate

    func AgoraRtcMediaPlayer(_ playerKit: AgoraRtcMediaPlayerProtocol,
                             didChangedTo state: AgoraMediaPlayerState,
                             reason: AgoraMediaPlayerReason) {
        DispatchQueue.main.async { [weak self] in
            guard let self = self else { return }

            switch state {
            case .opening:
                print("正在打开媒体源")

            case .playing:
                self.controlView.updatePlayButton(isPlaying: true)
                print("正在播放")

            case .paused:
                self.controlView.updatePlayButton(isPlaying: false)
                print("已暂停")

            case .stopped:
                self.controlView.updatePlayButton(isPlaying: false)
                print("已停止")

            case .failed:
                print("播放失败，错误原因：\(reason.rawValue)")
                self.showAlert(message: "播放失败，错误原因：\(reason.rawValue)")

            default:
                break
            }
        }
    }

    func AgoraRtcMediaPlayer(_ playerKit: AgoraRtcMediaPlayerProtocol,
                             didChangedTo position: Int) {
        DispatchQueue.main.async { [weak self] in
            guard let self = self else { return }
            let duration = self.playerKit.getDuration()
            guard duration > 0 else { return }

            let progress = Float(position) / Float(duration)
            let currentTime = self.formatTime(position)
            let totalTime = self.formatTime(duration)

            self.controlView.updateProgress(progress,
                                            currentTime: currentTime,
                                            totalTime: totalTime)
        }
    }
}

extension YHBasePlayerViewController: AgoraRtcEngineDelegate {
    // MARK: - AgoraRtcEngineDelegate

    func rtcEngine(_ engine: AgoraRtcEngineKit, didOccurWarning warningCode: AgoraWarningCode) {
        print("Warning: \(warningCode.rawValue)")
    }

    func rtcEngine(_ engine: AgoraRtcEngineKit, didOccurError errorCode: AgoraErrorCode) {
        DispatchQueue.main.async { [weak self] in
            self?.showAlert(message: "RTC错误：\(errorCode.rawValue)")
        }
    }
}

extension YHBasePlayerViewController {
    // MARK: - Helper Methods

    private func formatTime(_ timeInMilliseconds: Int) -> String {
        let totalSeconds = timeInMilliseconds / 1000
        let minutes = totalSeconds / 60
        let seconds = totalSeconds % 60
        return String(format: "%02d:%02d", minutes, seconds)
    }

    func showAlert(message: String) {
        let alert = UIAlertController(title: "提示",
                                      message: message,
                                      preferredStyle: .alert)
        alert.addAction(UIAlertAction(title: "确定", style: .default))
        present(alert, animated: true)
    }
}
