//
//  YHVODPlayerViewController.swift
//  galaxy
//
//  Created by alexzzw on 2024/11/25.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import AgoraRtcKit
import UIKit

class YHVODPlayerViewController: YHBasePlayerViewController {
    private let videoInfo: YHVideoInfo
    private var playConfig: YHVideoPlayConfig
    
    init(videoInfo: YHVideoInfo, playConfig: YHVideoPlayConfig = YHVideoPlayConfig()) {
        self.videoInfo = videoInfo
        self.playConfig = playConfig
        super.init(nibName: nil, bundle: nil)
    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        setupVideoInfo()
        startPlayback()
    }
    
    private func setupVideoInfo() {
        // 设置视频标题
        title = videoInfo.title
        
        // 设置作者信息
        setupAuthorInfo()
        
        // 设置播放器配置
        setupPlayerConfig()
    }
    
    private func setupAuthorInfo() {
        // 添加作者信息视图
        let authorInfoView = YHVideoAuthorInfoView(author: videoInfo.author)
        view.addSubview(authorInfoView)
        
        authorInfoView.snp.makeConstraints { make in
            make.top.equalTo(playerView.snp.bottom)
            make.left.right.equalToSuperview()
            make.height.equalTo(60)
        }
    }
    
    private func setupPlayerConfig() {
        // 设置播放器配置
        if playConfig.muteOnStart {
            playerKit.adjustPlayoutVolume(0)
        }
    }
    
    private func startPlayback() {
        // 获取合适的视频URL
        let networkType: YHNetworkType = getNetworkType()
        if let videoUrl = videoInfo.getBestQualityUrl(for: networkType) {
            play(with: videoUrl)
        } else {
            //showAlert(message: "无法获取视频地址")
        }
    }
    
    private func getNetworkType() -> YHNetworkType {
        // 实现网络类型检测逻辑
        return .wifi
    }
    
    // MARK: - Player Control
    private func play(with url: String) {
        let mediaSource = AgoraMediaSource()
        mediaSource.url = url
        mediaSource.autoPlay = true
        
        let result = playerKit.open(with: mediaSource)
        if result != 0 {
            showAlert(message: "播放失败，错误码：\(result)")
        }
    }
    
    private func updatePlayCount() {
        // 更新播放次数的逻辑
    }
    
}

// 作者信息视图
class YHVideoAuthorInfoView: UIView {
    private let author: YHVideoAuthor
    
    private lazy var avatarImageView: UIImageView = {
        let imageView = UIImageView()
        imageView.layer.cornerRadius = 20
        imageView.layer.masksToBounds = true
        imageView.contentMode = .scaleAspectFill
        return imageView
    }()
    
    private lazy var nicknameLabel: UILabel = {
        let label = UILabel()
        label.font = .systemFont(ofSize: 16, weight: .medium)
        return label
    }()
    
    private lazy var followButton: UIButton = {
        let button = UIButton(type: .system)
        button.layer.cornerRadius = 15
        button.clipsToBounds = true
        return button
    }()
    
    init(author: YHVideoAuthor) {
        self.author = author
        super.init(frame: .zero)
        setupUI()
    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    private func setupUI() {
        addSubview(avatarImageView)
        addSubview(nicknameLabel)
        addSubview(followButton)
        
        // 设置约束
        avatarImageView.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(16)
            make.centerY.equalToSuperview()
            make.size.equalTo(CGSize(width: 40, height: 40))
        }
        
        nicknameLabel.snp.makeConstraints { make in
            make.left.equalTo(avatarImageView.snp.right).offset(12)
            make.centerY.equalToSuperview()
        }
        
        followButton.snp.makeConstraints { make in
            make.right.equalToSuperview().offset(-16)
            make.centerY.equalToSuperview()
            make.width.equalTo(80)
            make.height.equalTo(30)
        }
        
        // 设置数据
        nicknameLabel.text = author.nickname
        updateFollowButton()
        
        // 加载头像
        if let avatarUrl = author.avatarUrl {
            // 使用SDWebImage或其他图片加载库加载头像
            // avatarImageView.sd_setImage(with: URL(string: avatarUrl))
        }
    }
    
    private func updateFollowButton() {
        let title = author.isFollowed ? "已关注" : "关注"
        let backgroundColor = author.isFollowed ? UIColor.systemGray3 : UIColor.systemBlue
        
        followButton.setTitle(title, for: .normal)
        followButton.backgroundColor = backgroundColor
        followButton.setTitleColor(.white, for: .normal)
    }
}
