//
//  YHPlayerControlView.swift
//  galaxy
//
//  Created by alexzzw on 2024/11/25.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHPlayerControlView: UIView {
    // MARK: - Properties
    weak var delegate: YHMediaPlayerViewDelegate?
    
    // MARK: - UI Components
    private lazy var topBar: UIView = {
        let view = UIView()
        view.backgroundColor = UIColor.black.withAlphaComponent(0.5)
        return view
    }()
    
    private lazy var backButton: UIButton = {
        let button = UIButton(type: .system)
        button.setImage(UIImage(systemName: "chevron.left"), for: .normal)
        button.tintColor = .white
        button.addTarget(self, action: #selector(backButtonTapped), for: .touchUpInside)
        return button
    }()
    
    private lazy var titleLabel: UILabel = {
        let label = UILabel()
        label.textColor = .white
        label.font = .systemFont(ofSize: 16, weight: .medium)
        return label
    }()
    
    private lazy var bottomBar: UIView = {
        let view = UIView()
        view.backgroundColor = UIColor.black.withAlphaComponent(0.5)
        return view
    }()
    
    private lazy var playButton: UIButton = {
        let button = UIButton(type: .system)
        button.setImage(UIImage(systemName: "play.fill"), for: .normal)
        button.tintColor = .white
        button.addTarget(self, action: #selector(playButtonTapped), for: .touchUpInside)
        return button
    }()
    
    private lazy var progressSlider: UISlider = {
        let slider = UISlider()
        slider.minimumTrackTintColor = .systemBlue
        slider.maximumTrackTintColor = .gray
        slider.setThumbImage(UIImage(systemName: "circle.fill")?.withTintColor(.white, renderingMode: .alwaysOriginal), for: .normal)
        slider.addTarget(self, action: #selector(sliderValueChanged(_:)), for: .valueChanged)
        return slider
    }()
    
    private lazy var timeLabel: UILabel = {
        let label = UILabel()
        label.textColor = .white
        label.font = .systemFont(ofSize: 12)
        label.text = "00:00 / 00:00"
        return label
    }()
    
    private lazy var qualityButton: UIButton = {
        let button = UIButton(type: .system)
        button.setTitle("清晰度", for: .normal)
        button.setTitleColor(.white, for: .normal)
        button.addTarget(self, action: #selector(qualityButtonTapped), for: .touchUpInside)
        return button
    }()
    
    private lazy var fullscreenButton: UIButton = {
        let button = UIButton(type: .system)
        button.setImage(UIImage(systemName: "arrow.up.left.and.arrow.down.right"), for: .normal)
        button.tintColor = .white
        button.addTarget(self, action: #selector(fullscreenButtonTapped), for: .touchUpInside)
        return button
    }()
    
    // MARK: - Initialization
    override init(frame: CGRect) {
        super.init(frame: frame)
        setupUI()
    }
    
    required init?(coder: NSCoder) {
        super.init(coder: coder)
        setupUI()
    }
    
    // MARK: - Setup
    private func setupUI() {
        addSubview(topBar)
        addSubview(bottomBar)
        
        topBar.addSubview(backButton)
        topBar.addSubview(titleLabel)
        
        bottomBar.addSubview(playButton)
        bottomBar.addSubview(progressSlider)
        bottomBar.addSubview(timeLabel)
        bottomBar.addSubview(qualityButton)
        bottomBar.addSubview(fullscreenButton)
        
        setupConstraints()
    }
    
    private func setupConstraints() {
        topBar.snp.makeConstraints { make in
            make.top.left.right.equalToSuperview()
            make.height.equalTo(44)
        }
        
        backButton.snp.makeConstraints { make in
            make.left.equalTo(topBar).offset(16)
            make.centerY.equalTo(topBar)
            make.size.equalTo(CGSize(width: 44, height: 44))
        }
        
        titleLabel.snp.makeConstraints { make in
            make.center.equalTo(topBar)
        }
        
        bottomBar.snp.makeConstraints { make in
            make.left.right.bottom.equalToSuperview()
            make.height.equalTo(44)
        }
        
        playButton.snp.makeConstraints { make in
            make.left.equalTo(bottomBar).offset(16)
            make.centerY.equalTo(bottomBar)
            make.size.equalTo(CGSize(width: 44, height: 44))
        }
        
        progressSlider.snp.makeConstraints { make in
            make.left.equalTo(playButton.snp.right).offset(8)
            make.right.equalTo(timeLabel.snp.left).offset(-8)
            make.centerY.equalTo(bottomBar)
        }
        
        timeLabel.snp.makeConstraints { make in
            make.right.equalTo(qualityButton.snp.left).offset(-8)
            make.centerY.equalTo(bottomBar)
            make.width.equalTo(100)
        }
        
        qualityButton.snp.makeConstraints { make in
            make.right.equalTo(fullscreenButton.snp.left).offset(-8)
            make.centerY.equalTo(bottomBar)
        }
        
        fullscreenButton.snp.makeConstraints { make in
            make.right.equalTo(bottomBar).offset(-16)
            make.centerY.equalTo(bottomBar)
            make.size.equalTo(CGSize(width: 44, height: 44))
        }
    }
    
    // MARK: - Actions
    @objc private func backButtonTapped() {
        // Handle back action
    }
    
    @objc private func playButtonTapped() {
        delegate?.didTapPlayButton()
    }
    
    @objc private func sliderValueChanged(_ slider: UISlider) {
        delegate?.didSeekToPosition(slider.value)
    }
    
    @objc private func qualityButtonTapped() {
        showQualitySelector()
    }
    
    @objc private func fullscreenButtonTapped() {
        delegate?.didToggleFullscreen()
    }
    
    private func showQualitySelector() {
        let alert = UIAlertController(title: "选择清晰度", message: nil, preferredStyle: .actionSheet)
        
        YHVideoQuality.allCases.forEach { quality in
            let action = UIAlertAction(title: quality.rawValue, style: .default) { [weak self] _ in
                self?.delegate?.didChangeQuality(quality)
            }
            alert.addAction(action)
        }
        
        alert.addAction(UIAlertAction(title: "取消", style: .cancel))
        
        if let viewController = self.window?.rootViewController {
            viewController.present(alert, animated: true)
        }
    }
}

// MARK: - YHPlayerControlView Extension
extension YHPlayerControlView {
    func updatePlayButton(isPlaying: Bool) {
        let imageName = isPlaying ? "pause.fill" : "play.fill"
        playButton.setImage(UIImage(systemName: imageName), for: .normal)
    }
    
    func updateProgress(_ progress: Float, currentTime: String, totalTime: String) {
        progressSlider.value = progress
        timeLabel.text = "\(currentTime) / \(totalTime)"
    }
    
    func setTitle(_ title: String) {
        titleLabel.text = title
    }
    
    func showControls(_ show: Bool) {
        UIView.animate(withDuration: 0.3) {
            self.alpha = show ? 1.0 : 0.0
        }
    }
}
